/*
 *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
 *
 *  $Id: interface.c,v 3.3 2002/03/04 05:10:04 shuu Exp shuu $
 *
 *  Can be freely distributed and used under the terms of the GNU GPL.
 */
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>

#include	"murasaki.h"
#include	"murasaki_net.h"

/*
 * format: s
 */
int
get_interface(MU_net_config_t *config)
{
	char *ptr;

	ptr = getenv("INTERFACE");
	if (ptr == NULL)
		return INVALID;

	config->name = strdup(ptr);
	if (config->name == NULL)
		return INVALID;
	DPRINTF(LOG_LEVEL,"name \"%s\"",config->name);

	return GOOD;
}

